@@ -6,23 +6,24 @@
 "use strict";
 
 module.exports = function getPaths(path) {
+	if (path === "/") return { paths: ["/"], segments: [""] };
 	const parts = path.split(/(.*?[\\/]+)/);
 	const paths = [path];
-	const seqments = [parts[parts.length - 1]];
+	const segments = [parts[parts.length - 1]];
 	let part = parts[parts.length - 1];
 	path = path.substr(0, path.length - part.length - 1);
 	for (let i = parts.length - 2; i > 2; i -= 2) {
 		paths.push(path);
 		part = parts[i];
 		path = path.substr(0, path.length - part.length) || "/";
-		seqments.push(part.substr(0, part.length - 1));
+		segments.push(part.substr(0, part.length - 1));
 	}
 	part = parts[1];
-	seqments.push(part);
+	segments.push(part);
 	paths.push(part);
 	return {
 		paths: paths,
-		seqments: seqments
+		segments: segments
 	};
 };
 
