@@ -1,7 +1,12 @@
-require("should");
+const should = require("should");
 
-var { Volume } = require("memfs");
-var { ResolverFactory } = require("../");
+const path = require("path");
+const { Volume } = require("memfs");
+const { ResolverFactory } = require("../");
+const CachedInputFileSystem = require("../lib/CachedInputFileSystem");
+const fs = require("fs");
+
+const nodeFileSystem = new CachedInputFileSystem(fs, 4000);
 
 describe("alias", function () {
 	var resolver;
@@ -34,6 +39,9 @@ describe("alias", function () {
 				recursive: "recursive/dir",
 				"/d/dir": "/c/dir",
 				"/d/index.js": "/c/index",
+				// alias configuration should work
+				"#": "/c/dir",
+				"@": "/c/dir",
 				ignored: false
 			},
 			modules: "/",
@@ -56,6 +64,14 @@ describe("alias", function () {
 			.resolveSync({}, "/", "aliasA/dir/index")
 			.should.be.eql("/a/dir/index");
 	});
+	it('should resolve "#" alias', () => {
+		resolver.resolveSync({}, "/", "#").should.be.eql("/c/dir/index");
+		resolver.resolveSync({}, "/", "#/index").should.be.eql("/c/dir/index");
+	});
+	it('should resolve "@" alias', () => {
+		resolver.resolveSync({}, "/", "@").should.be.eql("/c/dir/index");
+		resolver.resolveSync({}, "/", "@/index").should.be.eql("/c/dir/index");
+	});
 	it("should resolve an ignore module", () => {
 		resolver.resolveSync({}, "/", "ignored").should.be.eql(false);
 	});
@@ -144,4 +160,20 @@ describe("alias", function () {
 			}
 		);
 	});
+
+	it("should work with absolute paths", done => {
+		const resolver = ResolverFactory.createResolver({
+			alias: {
+				[path.resolve(__dirname, "fixtures", "foo")]: false
+			},
+			modules: path.resolve(__dirname, "fixtures"),
+			fileSystem: nodeFileSystem
+		});
+
+		resolver.resolve({}, __dirname, "foo/index", {}, (err, result) => {
+			if (err) done(err);
+			should(result).be.eql(false);
+			done();
+		});
+	});
 });
